=======
Recipes
=======

Recipes are simple guides to solving common problems that occur when creating
e-commerce projects.

Customisation
-------------

.. toctree::
    :maxdepth: 1

    how_to_customise_models
    how_to_customise_templates
    how_to_disable_an_app
    how_to_change_a_url
    how_to_customise_a_view
    how_to_configure_the_dashboard_navigation
    how_to_customise_oscar_communications

Customers
---------

.. toctree::
    :maxdepth: 1

    use_a_custom_user_model

Catalogue
---------

.. toctree::
    :maxdepth: 1

    how_to_create_categories
    importing_a_catalogue

Pricing, stock and availability
-------------------------------

.. toctree::
    :maxdepth: 1

    enforcing_stock_rules
    how_to_configure_stock_messaging

Payment
-------

.. toctree::
    :maxdepth: 1

    how_to_integrate_payment
    how_to_handle_us_taxes

Shipping
--------

.. toctree::
    :maxdepth: 1

    how_to_configure_shipping

Order processing
----------------

.. toctree::
    :maxdepth: 1

    how_to_set_up_order_processing

Offers
------

.. toctree::
    :maxdepth: 1

    how_to_create_a_custom_range
    how_to_create_a_custom_condition
    how_to_create_a_custom_benefit

Appearance
----------

.. toctree::
    :maxdepth: 1

    how_to_handle_statics

Deployment and setup
--------------------

.. toctree::
    :maxdepth: 1

    how_to_setup_solr

